@@ -3,8 +3,10 @@ from __future__ import annotations
 import json
 import logging
 import random
+import warnings
 from abc import ABC, abstractmethod
 from collections.abc import Sequence
+from copy import copy
 from typing import Any
 
 import datasets
@@ -62,15 +64,21 @@ class AbsTask(ABC):
     dataset: dict[HFSubset, DatasetDict] | None = None  # type: ignore
     data_loaded: bool = False
     is_multilingual: bool = False
+    hf_subsets: list[HFSubset]
 
     def __init__(self, seed: int = 42, **kwargs: Any):
         self.save_suffix = kwargs.get("save_suffix", "")
+        if self.save_suffix:
+            warnings.warn(
+                "`save_suffix` will be removed in v2.0.0.", DeprecationWarning
+            )
 
         self.seed = seed
         random.seed(self.seed)
         np.random.seed(self.seed)
         torch.manual_seed(self.seed)
         torch.cuda.manual_seed_all(self.seed)
+        self.hf_subsets = list(self.metadata.hf_subsets_to_langscripts.keys())
 
     def check_if_dataset_is_superseded(self):
         """Check if the dataset is superseded by a newer version"""
@@ -110,9 +118,12 @@ class AbsTask(ABC):
         self.dataset: dict[HFSubset, DatasetDict]
 
         scores = {}
-        hf_subsets = list(self.dataset.keys()) if self.is_multilingual else ["default"]
+        if self.hf_subsets is None:
+            hf_subsets = list(self.dataset.keys())
+        else:
+            hf_subsets = copy(self.hf_subsets)
 
-        if subsets_to_run is not None:
+        if subsets_to_run is not None:  # allow overwrites of pre-filtering
             hf_subsets = [s for s in hf_subsets if s in subsets_to_run]
 
         for hf_subset in hf_subsets:
@@ -218,16 +229,13 @@ class AbsTask(ABC):
                 )
                 descriptive_stats[split][hf_subset_stat] = {}
 
-                eval_langs = (
-                    list(self.metadata.eval_langs.keys())
-                    if isinstance(self.metadata.eval_langs, dict)
-                    else self.metadata.eval_langs
+                pbar_subsets = tqdm.tqdm(
+                    self.metadata.hf_subsets_to_langscripts,
+                    desc="Processing Languages...",
                 )
-
-                pbar_subsets = tqdm.tqdm(eval_langs, desc="Processing Languages...")
                 for hf_subset in pbar_subsets:
-                    pbar_subsets.set_postfix_str(f"Language: {hf_subset}")
-                    logger.info(f"Processing metadata for language {hf_subset}")
+                    pbar_subsets.set_postfix_str(f"Huggingface subset: {hf_subset}")
+                    logger.info(f"Processing metadata for subset {hf_subset}")
                     split_details = self._calculate_metrics_from_split(split, hf_subset)
                     descriptive_stats[split][hf_subset_stat][hf_subset] = split_details
             else:
@@ -247,17 +255,17 @@ class AbsTask(ABC):
 
     @property
     def metadata_dict(self) -> dict[str, Any]:
+        warnings.warn(
+            "`metadata_dict` will be removed in v2.0. Use task.metadata instead.",
+            DeprecationWarning,
+        )
         return dict(self.metadata)
 
     @property
     def languages(self) -> list[str]:
         """Returns the languages of the task"""
-        # check if self.hf_subsets is set
-        if self.is_multilingual and hasattr(self, "hf_subsets"):
-            assert isinstance(
-                self.metadata.eval_langs, dict
-            ), "eval_langs must be dict for multilingual tasks"
-            eval_langs = self.metadata.eval_langs
+        if self.hf_subsets:
+            eval_langs = self.metadata.hf_subsets_to_langscripts
             languages = []
 
             for lang in self.hf_subsets:
@@ -274,42 +282,89 @@ class AbsTask(ABC):
         self._eval_splits = eval_splits
         return self
 
+    def filter_modalities(
+        self, modalities: list[str] | None, exclusive_modality_filter: bool = False
+    ) -> AbsTask:
+        """Filter the modalities of the task.
+
+        Args:
+        modalities: A list of modalities to filter by. If None, the task is returned unchanged.
+        exclusive_modality_filter: If True, only keep tasks where _all_ filter modalities are included in the
+            task's modalities and ALL task modalities are in filter modalities (exact match).
+            If False, keep tasks if _any_ of the task's modalities match the filter modalities.
+        """
+        if modalities is None:
+            return self
+        filter_modalities_set = set(modalities)
+        task_modalities_set = set(self.modalities)
+        if exclusive_modality_filter:
+            if not (filter_modalities_set == task_modalities_set):
+                self.metadata.modalities = []
+        else:
+            if not filter_modalities_set.intersection(task_modalities_set):
+                self.metadata.modalities = []
+        return self
+
     def filter_languages(
-        self, languages: list[str] | None, script: list[str] | None = None
+        self,
+        languages: list[str] | None,
+        script: list[str] | None = None,
+        hf_subsets: list[HFSubset] | None = None,
+        exclusive_language_filter: bool = False,
     ) -> AbsTask:
         """Filter the languages of the task.
 
         Args:
             languages: list of languages to filter the task by can be either a 3-letter langauge code (e.g. "eng") or also include the script
                 (e.g. "eng-Latn")
-            script: list of scripts to filter the task by. Will be ignored if language code specified the script. If None, all scripts are included.
+            script: A list of scripts to filter the task by. Will be ignored if language code specified the script. If None, all scripts are included.
                 If the language code does not specify the script the intersection of the language and script will be used.
+            hf_subsets: A list of huggingface subsets to filter on. This is useful if a dataset have multiple subsets containing the desired language,
+                but you only want to test on one. An example is STS22 which e.g. have both "en" and "de-en" which both contains English.
+            exclusive_language_filter: Some datasets contains more than one language e.g. for STS22 the subset "de-en" contain eng and deu. If
+                exclusive_language_filter is set to False both of these will be kept, but if set to True only those that contains all the languages
+                specified will be kept.
         """
         lang_scripts = LanguageScripts.from_languages_and_scripts(languages, script)
 
         subsets_to_keep = []
 
-        if not isinstance(self.metadata.eval_langs, dict):
-            self.hf_subsets = self.metadata.eval_langs
-            return self
+        for hf_subset, langs in self.metadata.hf_subsets_to_langscripts.items():
+            if (hf_subsets is not None) and (hf_subset not in hf_subsets):
+                continue
+            if exclusive_language_filter is False:
+                for langscript in langs:
+                    if lang_scripts.contains_language(
+                        langscript
+                    ) or lang_scripts.contains_script(langscript):
+                        subsets_to_keep.append(hf_subset)
+                        break
 
-        for hf_subset, langs in self.metadata.eval_langs.items():
-            for langscript in langs:
-                if lang_scripts.contains_language(
-                    langscript
-                ) or lang_scripts.contains_script(langscript):
+            if exclusive_language_filter is True and languages:
+                if lang_scripts.contains_languages(langs):
                     subsets_to_keep.append(hf_subset)
-                    break
 
         self.hf_subsets = subsets_to_keep
         return self
 
+    @property
+    def is_aggregate(
+        self,
+    ) -> bool:  # Overrided by subclasses (AbsTaskAggregate) that are aggregate
+        """Whether the task is aggregate. Subclasses that are aggregate should override this with `True`."""
+        return False
+
     @property
     def eval_splits(self) -> list[str]:
         if self._eval_splits:
             return self._eval_splits
         return self.metadata.eval_splits
 
+    @property
+    def modalities(self) -> list[str]:
+        """Returns the modalities of the task"""
+        return self.metadata.modalities
+
     def __repr__(self) -> str:
         """Format the representation of the task such that it appears as:
 
