@@ -14,7 +14,7 @@ Corpus = Union[list[dict[str, str]], dict[str, list[str]]]
 
 class PromptType(str, Enum):
     query = "query"
-    passage = "passage"
+    document = "document"
 
 
 @runtime_checkable
