@@ -4,7 +4,8 @@ import json
 import logging
 import os
 import traceback
-from collections.abc import Iterable
+import warnings
+from collections.abc import Iterable, Sequence
 from copy import copy, deepcopy
 from datetime import datetime
 from itertools import chain
@@ -31,9 +32,12 @@ logger = logging.getLogger(__name__)
 
 
 class MTEB:
+    _tasks: Iterable[str | AbsTask] | None
+    tasks: list[AbsTask]
+
     def __init__(
         self,
-        tasks: Iterable[str | AbsTask] | None = None,
+        tasks: Sequence[str | AbsTask] | None = None,
         *,
         task_types: list[str] | None = None,
         task_categories: list[str] | None = None,
@@ -61,15 +65,14 @@ class MTEB:
         self.deprecation_warning(
             task_types, task_categories, task_langs, tasks, version
         )
-
         if tasks is not None:
             self._tasks = tasks
             if isinstance(tasks[0], Benchmark):
                 self.benchmarks = tasks
-                self._tasks = list(chain.from_iterable(tasks))
-            assert (
-                task_types is None and task_categories is None
-            ), "Cannot specify both `tasks` and `task_types`/`task_categories`"
+                self._tasks = self._tasks = list(chain.from_iterable(tasks))  # type: ignore
+            assert task_types is None and task_categories is None, (
+                "Cannot specify both `tasks` and `task_types`/`task_categories`"
+            )
         else:
             self._task_types = task_types
             self._task_categories = task_categories
@@ -93,29 +96,29 @@ class MTEB:
         self, task_types, task_categories, task_langs, tasks, version
     ):
         if task_types is not None:
-            logger.warning(
-                "The `task_types` argument is deprecated and will be removed in the next release. "
+            warnings.warn(
+                "The `task_types` argument is deprecated and will be removed in the 2.0 release. "
                 + "Please use `tasks = mteb.get_tasks(... task_types = [...])` to filter tasks instead."
             )
         if task_categories is not None:
-            logger.warning(
-                "The `task_categories` argument is deprecated and will be removed in the next release. "
+            warnings.warn(
+                "The `task_categories` argument is deprecated and will be removed in the 2.0 release. "
                 + "Please use `tasks = mteb.get_tasks(... categories = [...])` to filter tasks instead."
             )
         if task_langs is not None:
-            logger.warning(
-                "The `task_langs` argument is deprecated and will be removed in the next release. "
+            warnings.warn(
+                "The `task_langs` argument is deprecated and will be removed in the 2.0 release. "
                 + "Please use `tasks = mteb.get_tasks(... languages = [...])` to filter tasks instead. "
                 + "Note that this uses 3 letter language codes (ISO 639-3)."
             )
         if version is not None:
-            logger.warning(
-                "The `version` argument is deprecated and will be removed in the next release."
+            warnings.warn(
+                "The `version` argument is deprecated and will be removed in the 2.0 release."
             )
         task_contains_strings = any(isinstance(x, str) for x in tasks or [])
         if task_contains_strings:
-            logger.warning(
-                "Passing task names as strings is deprecated and will be removed in the next release. "
+            warnings.warn(
+                "Passing task names as strings is deprecated and will be removed in 2.0 release. "
                 + "Please use `tasks = mteb.get_tasks(tasks=[...])` method to get tasks instead."
             )
 
@@ -253,7 +256,7 @@ class MTEB:
                         f"WARNING: Unknown tasks: {unknown_str}. Known tasks: {known_str}."
                     )
             # add task if subclass of mteb.tasks
-            self.tasks.extend([x for x in self._tasks if isinstance(x, AbsTask)])
+            self.tasks.extend([x for x in self._tasks if isinstance(x, (AbsTask))])
             return
 
         # Otherwise use filters to select tasks
@@ -463,6 +466,29 @@ class MTEB:
                 f"\n\n********************** Evaluating {task.metadata.name} **********************"
             )
 
+            if task.is_aggregate:
+                self_ = MTEB(tasks=task.metadata.tasks)
+                task_results = self_.run(
+                    model,
+                    verbosity=verbosity - 1,
+                    output_folder=output_folder,
+                    eval_splits=eval_splits,
+                    eval_subsets=eval_subsets,
+                    overwrite_results=overwrite_results,
+                    raise_error=raise_error,
+                    co2_tracker=co2_tracker,
+                    encode_kwargs=encode_kwargs,
+                    **kwargs,
+                )
+                new_results = task.combine_task_results(task_results)
+                evaluation_results.append(new_results)
+
+                if output_path:
+                    save_path = output_path / f"{task.metadata.name}.json"
+                    new_results.to_disk(save_path)
+                del self.tasks[0]
+                continue
+
             if "bm25s" in meta.name and task.metadata.type != "Retrieval":
                 logger.warning(
                     f"bm25s only supports Retrieval tasks, but the task type is {task.metadata.type}. Skipping task."
@@ -470,10 +496,26 @@ class MTEB:
                 del self.tasks[0]  # empty memory
                 continue
 
+            # NOTE: skip evaluation if the model does not support all of the task's modalities.
+            # If the model covers more than the task's modalities, evaluation will still be run.
+            sorted_task_modalities = sorted(task.metadata.modalities)
+            if meta.modalities is not None and any(
+                m not in meta.modalities for m in sorted_task_modalities
+            ):
+                logger.info(
+                    f"{meta.name} only supports {meta.modalities}, but the task modalities are {sorted_task_modalities}."
+                )
+                del self.tasks[0]  # empty memory
+                continue
+
             task_eval_splits = (
                 eval_splits if eval_splits is not None else task.eval_splits
             )
-            task_subsets = list(task.metadata.hf_subsets_to_langscripts.keys())
+            task_subsets = (
+                task.hf_subsets
+                if task.hf_subsets
+                else list(task.metadata.hf_subsets_to_langscripts.keys())
+            )
 
             existing_results = None
             save_path = None
