@@ -180,7 +180,7 @@ class RerankingEvaluator(Evaluator):
             all_docs,
             model,
             task_name=self.task_name,
-            prompt_type=PromptType.passage,
+            prompt_type=PromptType.document,
             **self.encode_kwargs,
         )
 
@@ -245,7 +245,7 @@ class RerankingEvaluator(Evaluator):
                 model.encode(
                     docs,
                     task_name=self.task_name,
-                    prompt_type=PromptType.passage,
+                    prompt_type=PromptType.document,
                     **self.encode_kwargs,
                 )
             )
@@ -293,7 +293,7 @@ class RerankingEvaluator(Evaluator):
             model.encode(
                 all_docs,
                 task_name=self.task_name,
-                prompt_type=PromptType.passage,
+                prompt_type=PromptType.document,
                 **self.encode_kwargs,
             )
         )
@@ -345,7 +345,7 @@ class RerankingEvaluator(Evaluator):
                     model.encode(
                         docs,
                         task_name=self.task_name,
-                        prompt_type=PromptType.passage,
+                        prompt_type=PromptType.document,
                         **self.encode_kwargs,
                     )
                 )
