@@ -5,8 +5,10 @@ import re
 from collections import defaultdict
 
 import gradio as gr
+import matplotlib.pyplot as plt
 import numpy as np
 import pandas as pd
+from matplotlib.colors import LinearSegmentedColormap
 from pandas.api.types import is_numeric_dtype
 
 from mteb.models.overview import get_model_meta
@@ -49,23 +51,6 @@ def split_on_capital(s: str) -> str:
     return " ".join(re.findall(r"[A-Z]?[a-z]+|[A-Z]+(?=[A-Z]|$)", s))
 
 
-def get_column_widths(df: pd.DataFrame) -> list[str]:
-    widths = []
-    for column_name in df.columns:
-        column_word_lengths = [len(word) for word in column_name.split()]
-        if is_numeric_dtype(df[column_name]):
-            value_lengths = [len(f"{value:.2f}") for value in df[column_name]]
-        else:
-            value_lengths = [len(str(value)) for value in df[column_name]]
-        try:
-            max_length = max(max(column_word_lengths), max(value_lengths))
-            n_pixels = 35 + (max_length * 12.5)
-            widths.append(f"{n_pixels}px")
-        except Exception:
-            widths.append("50px")
-    return widths
-
-
 def get_column_types(df: pd.DataFrame) -> list[str]:
     types = []
     for column_name in df.columns:
@@ -76,6 +61,23 @@ def get_column_types(df: pd.DataFrame) -> list[str]:
     return types
 
 
+def get_column_widths(df: pd.DataFrame) -> list[str]:
+    # Please do not remove this function when refactoring.
+    # Column width calculation seeminlgy changes regularly with Gradio releases,
+    # and this piece of logic is good enough to quickly fix related issues.
+    widths = []
+    for column_name in df.columns:
+        column_word_lengths = [len(word) for word in column_name.split()]
+        if is_numeric_dtype(df[column_name]):
+            value_lengths = [len(f"{value:.2f}") for value in df[column_name]]
+        else:
+            value_lengths = [len(str(value)) for value in df[column_name]]
+        max_length = max(max(column_word_lengths), max(value_lengths))
+        n_pixels = 25 + (max_length * 10)
+        widths.append(f"{n_pixels}px")
+    return widths
+
+
 def get_means_per_types(per_task: pd.DataFrame):
     task_names_per_type = defaultdict(list)
     for task_name in per_task.columns:
@@ -88,7 +90,7 @@ def get_means_per_types(per_task: pd.DataFrame):
                 dict(
                     model_name=model_name,
                     task_type=task_type,
-                    score=scores[tasks].mean(),
+                    score=scores[tasks].mean(skipna=False),
                 )
             )
     return pd.DataFrame.from_records(records)
@@ -109,20 +111,24 @@ def format_max_tokens(max_tokens: float | None) -> str:
     return str(int(max_tokens))
 
 
-def get_zero_shot_emoji(model_meta, tasks):
-    if model_meta is None:
-        return "⚠️"
-    is_zero_shot = model_meta.is_zero_shot_on(tasks)
-    if is_zero_shot is None:
-        return "⚠️"
-    if is_zero_shot:
-        return "✅"
-    return "❌"
+def format_zero_shot(zero_shot_percentage: int):
+    if zero_shot_percentage == -1:
+        return "⚠️ NA"
+    return f"{zero_shot_percentage:.0f}%"
 
 
-def scores_to_tables(
-    scores_long: list[dict], search_query: str | None = None
-) -> tuple[gr.DataFrame, gr.DataFrame]:
+def create_light_green_cmap():
+    cmap = plt.cm.get_cmap("Greens")
+    num_colors = 256
+    half_colors = np.linspace(0, 0.5, num_colors)
+    half_cmap = [cmap(val) for val in half_colors]
+    light_green_cmap = LinearSegmentedColormap.from_list(
+        "LightGreens", half_cmap, N=256
+    )
+    return light_green_cmap
+
+
+def scores_to_tables(scores_long: list[dict], search_query: str | None = None):
     if not scores_long:
         no_results_frame = pd.DataFrame(
             {"No results": ["You can try relaxing your criteria"]}
@@ -142,6 +148,11 @@ def scores_to_tables(
         names = per_task.index.get_level_values("model_name")
         names = pd.Series(names, index=per_task.index)
         to_remove |= ~names.str.contains(search_query, regex=True)
+    if to_remove.all():
+        no_results_frame = pd.DataFrame(
+            {"No results": ["You can try relaxing your criteria"]}
+        )
+        return gr.DataFrame(no_results_frame), gr.DataFrame(no_results_frame)
     models_to_remove = list(per_task[to_remove].index)
     typed_mean = mean_per_type.mean(skipna=False, axis=1)
     overall_mean = per_task.mean(skipna=False, axis=1)
@@ -174,10 +185,19 @@ def scores_to_tables(
         "Number of Parameters",
         model_metas.map(lambda m: format_n_parameters(m.n_parameters)),
     )
+    joint_table.insert(
+        1,
+        "Memory Usage (MB)",
+        model_metas.map(
+            lambda m: str(int(m.memory_usage_mb)) if m.memory_usage_mb else "Unknown"
+        ),
+    )
     tasks = get_tasks(tasks=list(data["task_name"].unique()))
     joint_table.insert(
-        1, "Zero-shot", model_metas.map(lambda m: get_zero_shot_emoji(m, tasks))
+        1, "Zero-shot", model_metas.map(lambda m: m.zero_shot_percentage(tasks))
     )
+    joint_table["Zero-shot"] = joint_table["Zero-shot"].fillna(-1)
+    # joint_table = joint_table[joint_table["Zero-shot"].notna()]
     # Removing HF organization from model
     joint_table["model_name"] = joint_table["model_name"].map(
         lambda name: name.split("/")[-1]
@@ -207,36 +227,120 @@ def scores_to_tables(
         }
     )
     joint_table.insert(0, "Rank (Borda)", joint_table.pop("borda_rank"))
-    column_widths = get_column_widths(joint_table)
-    task_column_widths = get_column_widths(per_task)
-    # overriding for model name
-    column_widths[1] = "250px"
     column_types = get_column_types(joint_table)
     # setting model name column to markdown
     column_types[1] = "markdown"
     score_columns = ["Mean (Task)", "Mean (TaskType)", *mean_per_type.columns]
+
+    return joint_table, per_task, score_columns, column_types
+
+
+def apply_styling(
+    joint_table: pd.DataFrame,
+    per_task: pd.DataFrame,
+    score_columns: list[str],
+    column_types: list[str],
+) -> tuple[gr.DataFrame, gr.DataFrame]:
+    excluded_columns = [
+        "Rank (Borda)",
+        "Model",
+        "Number of Parameters",
+        "Embedding Dimensions",
+        "Max Tokens",
+        "Memory Usage (MB)",
+    ]
+    gradient_columns = [
+        col for col in joint_table.columns if col not in excluded_columns
+    ]
+    light_green_cmap = create_light_green_cmap()
+    numeric_data = joint_table.copy()
+    joint_table["Zero-shot"] = joint_table["Zero-shot"].apply(format_zero_shot)
     joint_table[score_columns] = joint_table[score_columns].map(format_scores)
-    joint_table_style = (
-        joint_table.style.format(
-            {**{column: "{:.2f}" for column in score_columns}, "Rank (Borda)": "{:.0f}"}
-        )
-        .highlight_min("Rank (Borda)", props="font-weight: bold")
-        .highlight_max(subset=score_columns, props="font-weight: bold")
+    joint_table_style = joint_table.style.format(
+        {
+            **dict.fromkeys(score_columns, "{:.2f}"),
+            "Rank (Borda)": "{:.0f}",
+        },
+        na_rep="",
     )
+    joint_table_style = joint_table_style.highlight_min(
+        "Rank (Borda)", props="font-weight: bold"
+    ).highlight_max(subset=score_columns, props="font-weight: bold")
+
+    # Apply background gradients for each selected column
+    for col in gradient_columns:
+        if col in joint_table.columns:
+            mask = numeric_data[col].notna()
+            if col != "Zero-shot":
+                gmap_values = numeric_data[col] * 100
+                cmap = light_green_cmap
+                joint_table_style = joint_table_style.background_gradient(
+                    cmap=cmap,
+                    subset=pd.IndexSlice[mask, col],
+                    gmap=gmap_values.loc[mask],
+                )
+            else:
+                gmap_values = numeric_data[col]
+                cmap = "RdYlGn"
+                joint_table_style = joint_table_style.background_gradient(
+                    cmap=cmap,
+                    subset=pd.IndexSlice[mask, col],
+                    vmin=50,
+                    vmax=100,
+                    gmap=gmap_values.loc[mask],
+                )
     task_score_columns = per_task.select_dtypes("number").columns
     per_task[task_score_columns] *= 100
     per_task_style = per_task.style.format(
-        "{:.2f}", subset=task_score_columns
+        "{:.2f}", subset=task_score_columns, na_rep=""
     ).highlight_max(subset=task_score_columns, props="font-weight: bold")
+    # TODO: uncomment this when Gradio fixes it.
+    # The fix is already merged and contained in this release: https://github.com/gradio-app/gradio/pull/11032
+    # It will be available in Gradio 5.25.3
+    # for col in task_score_columns:
+    #     if col != "Model":
+    #         mask = per_task[col].notna()
+    #         per_task_style = per_task_style.background_gradient(
+    #             cmap=light_green_cmap,
+    #             subset=pd.IndexSlice[mask, col],
+    #             gmap=per_task[col].loc[mask],
+    #         )
+    column_widths = get_column_widths(joint_table_style.data)
+    column_widths[0] = "100px"
+    column_widths[1] = "250px"
     return (
         gr.DataFrame(
             joint_table_style,
-            column_widths=column_widths,
             datatype=column_types,
             interactive=False,
+            pinned_columns=3,
+            column_widths=column_widths,
             wrap=True,
+            show_fullscreen_button=True,
+            show_copy_button=True,
+            show_search="filter",
         ),
         gr.DataFrame(
-            per_task_style, column_widths=task_column_widths, interactive=False
+            per_task_style,
+            interactive=False,
+            pinned_columns=1,
+            show_fullscreen_button=True,
+            show_copy_button=True,
+            show_search="filter",
         ),
     )
+
+
+def create_tables(
+    scores_long: list[dict], search_query: str | None = None
+) -> tuple[gr.DataFrame, gr.DataFrame]:
+    result = scores_to_tables(scores_long, search_query)
+    # dataframe with No Results is returned, so no need to apply styling
+    if len(result) == 2:
+        joint_table, per_task = result
+        return joint_table, per_task
+    joint_table, per_task, score_columns, column_types = result
+    summary_table, per_task_table = apply_styling(
+        joint_table, per_task, score_columns, column_types
+    )
+    return summary_table, per_task_table
