@@ -7,6 +7,7 @@ from typing import Any
 
 import numpy as np
 import torch
+
 from mteb.encoder_interface import PromptType
 from mteb.model_meta import ModelMeta
 from mteb.models.instruct_wrapper import InstructSentenceTransformerWrapper
@@ -37,10 +38,13 @@ class KALMWrapper(InstructSentenceTransformerWrapper):
         task = get_task(task_name)
 
         # to passage prompts won't be applied to passages
-        if not self.apply_instruction_to_passages and prompt_type == PromptType.passage:
+        if (
+            not self.apply_instruction_to_passages
+            and prompt_type == PromptType.document
+        ):
             instruction = None
             logger.info(
-                f"No instruction used, because prompt type = {prompt_type.passage}"
+                f"No instruction used, because prompt type = {prompt_type.document}"
             )
 
         if task.metadata.type in ["STS", "PairClassification", "Summarization"]:
@@ -375,26 +379,26 @@ KaLM_v2_task_prompts = {
     "ThuNewsClusteringS2S": "Identify the topic or theme of the given news articles based on the titles",
     "ThuNewsClusteringP2P": "Identify the topic or theme of the given news articles based on the titles and contents",
     "Cmnli-query": "Retrieve semantically similar text",
-    "Cmnli-passage": "Retrieve semantically similar text",
+    "Cmnli-document": "Retrieve semantically similar text",
     "Ocnli-query": "Retrieve semantically similar text",
-    "Ocnli-passage": "Retrieve semantically similar text",
+    "Ocnli-document": "Retrieve semantically similar text",
     "SprintDuplicateQuestions-query": "Retrieve semantically similar questions",
-    "SprintDuplicateQuestions-passage": "Retrieve semantically similar questions",
+    "SprintDuplicateQuestions-document": "Retrieve semantically similar questions",
     "TwitterSemEval2015-query": "Retrieve semantically similar text",
-    "TwitterSemEval2015-passage": "Retrieve semantically similar text",
+    "TwitterSemEval2015-document": "Retrieve semantically similar text",
     "TwitterURLCorpus-query": "Retrieve semantically similar text",
-    "TwitterURLCorpus-passage": "Retrieve semantically similar text",
+    "TwitterURLCorpus-document": "Retrieve semantically similar text",
     "CMedQAv1-reranking": "Given a query, retrieve documents that answer the query",
     "CMedQAv2-reranking": "Given a query, retrieve documents that answer the query",
     "MMarcoReranking": "Given a query, retrieve documents that answer the query",
     "T2Reranking": "Given a query, retrieve documents that answer the query",
     "AskUbuntuDupQuestions-query": "Retrieve semantically similar questions",
-    "AskUbuntuDupQuestions-passage": "Retrieve semantically similar questions",
+    "AskUbuntuDupQuestions-document": "Retrieve semantically similar questions",
     "MindSmallReranking": "Given a query, retrieve documents that answer the query",
     "SciDocsRR-query": "Retrieve relevant paper titles",
-    "SciDocsRR-passage": "Retrieve relevant paper titles",
+    "SciDocsRR-document": "Retrieve relevant paper titles",
     "StackOverflowDupQuestions-query": "Retrieve semantically similar questions",
-    "StackOverflowDupQuestions-passage": "Retrieve semantically similar questions",
+    "StackOverflowDupQuestions-document": "Retrieve semantically similar questions",
     "CmedqaRetrieval": "Given a query, retrieve documents that answer the query",
     "CovidRetrieval": "Given a query, retrieve documents that answer the query",
     "DuRetrieval": "Given a query, retrieve documents that answer the query",
@@ -407,29 +411,29 @@ KaLM_v2_task_prompts = {
     "ArguAna": "Given a query, retrieve documents that answer the query",
     "ClimateFEVER": "Given a query, retrieve documents that answer the query",
     "CQADupstackAndroidRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackAndroidRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackAndroidRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackEnglishRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackEnglishRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackEnglishRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackGamingRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackGamingRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackGamingRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackGisRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackGisRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackGisRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackMathematicaRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackMathematicaRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackMathematicaRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackPhysicsRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackPhysicsRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackPhysicsRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackProgrammersRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackProgrammersRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackProgrammersRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackStatsRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackStatsRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackStatsRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackTexRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackTexRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackTexRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackUnixRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackUnixRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackUnixRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackWebmastersRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackWebmastersRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackWebmastersRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackWordpressRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackWordpressRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackWordpressRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "DBPedia": "Given a query, retrieve documents that answer the query",
     "FEVER": "Given a query, retrieve documents that answer the query",
     "FiQA2018": "Given a query, retrieve documents that answer the query",
@@ -437,48 +441,48 @@ KaLM_v2_task_prompts = {
     "NFCorpus": "Given a query, retrieve documents that answer the query",
     "NQ": "Given a query, retrieve documents that answer the query",
     "QuoraRetrieval-query": "Retrieve semantically similar questions",
-    "QuoraRetrieval-passage": "Retrieve semantically similar questions",
+    "QuoraRetrieval-document": "Retrieve semantically similar questions",
     "SCIDOCS-query": "Given a query, retrieve documents that answer the query",
-    "SCIDOCS-passage": "Given a query, retrieve documents that answer the query",
+    "SCIDOCS-document": "Given a query, retrieve documents that answer the query",
     "SciFact": "Given a query, retrieve documents that answer the query",
     "Touche2020": "Given a query, retrieve documents that answer the query",
     "TRECCOVID": "Given a query, retrieve documents that answer the query",
     "AFQMC-query": "Retrieve semantically similar text",
-    "AFQMC-passage": "Retrieve semantically similar text",
+    "AFQMC-document": "Retrieve semantically similar text",
     "ATEC-query": "Retrieve semantically similar text",
-    "ATEC-passage": "Retrieve semantically similar text",
+    "ATEC-document": "Retrieve semantically similar text",
     "BQ-query": "Retrieve semantically similar text",
-    "BQ-passage": "Retrieve semantically similar text",
+    "BQ-document": "Retrieve semantically similar text",
     "LCQMC-query": "Retrieve semantically similar text",
-    "LCQMC-passage": "Retrieve semantically similar text",
+    "LCQMC-document": "Retrieve semantically similar text",
     "PAWSX-query": "Retrieve semantically similar text",
-    "PAWSX-passage": "Retrieve semantically similar text",
+    "PAWSX-document": "Retrieve semantically similar text",
     "QBQTC-query": "Retrieve semantically similar text",
-    "QBQTC-passage": "Retrieve semantically similar text",
+    "QBQTC-document": "Retrieve semantically similar text",
     "STSB-query": "Retrieve semantically similar text",
-    "STSB-passage": "Retrieve semantically similar text",
+    "STSB-document": "Retrieve semantically similar text",
     "BIOSSES-query": "Retrieve semantically similar text",
-    "BIOSSES-passage": "Retrieve semantically similar text",
+    "BIOSSES-document": "Retrieve semantically similar text",
     "SICK-R-query": "Retrieve semantically similar text",
-    "SICK-R-passage": "Retrieve semantically similar text",
+    "SICK-R-document": "Retrieve semantically similar text",
     "STS12-query": "Retrieve semantically similar text",
-    "STS12-passage": "Retrieve semantically similar text",
+    "STS12-document": "Retrieve semantically similar text",
     "STS13-query": "Retrieve semantically similar text",
-    "STS13-passage": "Retrieve semantically similar text",
+    "STS13-document": "Retrieve semantically similar text",
     "STS14-query": "Retrieve semantically similar text",
-    "STS14-passage": "Retrieve semantically similar text",
+    "STS14-document": "Retrieve semantically similar text",
     "STS15-query": "Retrieve semantically similar text",
-    "STS15-passage": "Retrieve semantically similar text",
+    "STS15-document": "Retrieve semantically similar text",
     "STS16-query": "Retrieve semantically similar text",
-    "STS16-passage": "Retrieve semantically similar text",
+    "STS16-document": "Retrieve semantically similar text",
     "STS17-query": "Retrieve semantically similar text",
-    "STS17-passage": "Retrieve semantically similar text",
+    "STS17-document": "Retrieve semantically similar text",
     "STS22-query": "Retrieve semantically similar text",
-    "STS22-passage": "Retrieve semantically similar text",
+    "STS22-document": "Retrieve semantically similar text",
     "STSBenchmark-query": "Retrieve semantically similar text",
-    "STSBenchmark-passage": "Retrieve semantically similar text",
+    "STSBenchmark-document": "Retrieve semantically similar text",
     "SummEval-query": "Retrieve semantically similar summaries",
-    "SummEval-passage": "Retrieve semantically similar summaries",
+    "SummEval-document": "Retrieve semantically similar summaries",
 }
 
 KaLM_X_task_prompts = {
@@ -530,7 +534,7 @@ KaLM_X_task_prompts = {
     "CMedQAv1-reranking-query": "Given a Chinese community medical question, retrieve replies that best answer the question",
     "CMedQAv2-reranking-query": "Given a Chinese community medical question, retrieve replies that best answer the question",
     "ArguAna-query": "Given a claim, find documents that refute the claim",
-    "ArguAna-passage": "Given a claim, find documents that refute the claim",
+    "ArguAna-document": "Given a claim, find documents that refute the claim",
     "ClimateFEVER-query": "Given a claim about climate change, retrieve documents that support or refute the claim",
     "ClimateFEVERHardNegatives-query": "Given a claim about climate change, retrieve documents that support or refute the claim",
     "DBPedia-query": "Given a query, retrieve relevant entity descriptions from DBPedia",
@@ -677,9 +681,9 @@ KaLM_X_task_prompts = {
     "MIRACLRetrievalHardNegatives-query": "Retrieval relevant passage for the given query",
     "CQADupstackRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackGamingRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackGamingRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackGamingRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
     "CQADupstackUnixRetrieval-query": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
-    "CQADupstackUnixRetrieval-passage": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
+    "CQADupstackUnixRetrieval-document": "Given a question, retrieve detailed question descriptions from Stackexchange that are duplicates to the given question",
 }
 
 KaLM_INSTRUCTION = "Instruct: {instruction} \n Query: "
