@@ -292,10 +292,22 @@ monot5_small = ModelMeta(
         fp_options="float16",
     ),
     name="castorini/monot5-small-msmarco-10k",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="77f8e3f7b1eb1afe353aa21a7c3a2fc8feca702e",
     release_date="2022-03-28",
+    n_parameters=None,
+    memory_usage_mb=None,
+    max_tokens=None,
+    embed_dim=None,
+    license=None,
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    training_datasets=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 monot5_base = ModelMeta(
@@ -306,10 +318,22 @@ monot5_base = ModelMeta(
         fp_options="float16",
     ),
     name="castorini/monot5-base-msmarco-10k",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="f15657ab3d2a5dd0b9a30c8c0b6a0a73c9cb5884",
     release_date="2022-03-28",
+    n_parameters=None,
+    memory_usage_mb=None,
+    max_tokens=None,
+    embed_dim=None,
+    license=None,
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    training_datasets=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 monot5_large = ModelMeta(
@@ -320,10 +344,22 @@ monot5_large = ModelMeta(
         fp_options="float16",
     ),
     name="castorini/monot5-large-msmarco-10k",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="48cfad1d8dd587670393f27ee8ec41fde63e3d98",
     release_date="2022-03-28",
+    n_parameters=None,
+    memory_usage_mb=None,
+    max_tokens=None,
+    embed_dim=None,
+    license=None,
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    training_datasets=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 monot5_3b = ModelMeta(
@@ -334,10 +370,22 @@ monot5_3b = ModelMeta(
         fp_options="float16",
     ),
     name="castorini/monot5-3b-msmarco-10k",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="bc0c419a438c81f592f878ce32430a1823f5db6c",
     release_date="2022-03-28",
+    n_parameters=None,
+    memory_usage_mb=None,
+    max_tokens=None,
+    embed_dim=None,
+    license=None,
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    training_datasets=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 flant5_base = ModelMeta(
@@ -348,7 +396,7 @@ flant5_base = ModelMeta(
         fp_options="float16",
     ),
     name="google/flan-t5-base",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="7bcac572ce56db69c1ea7c8af255c5d7c9672fc2",
     release_date="2022-10-21",
@@ -364,6 +412,17 @@ flant5_base = ModelMeta(
         "quasc": ["train"],
         "qed": ["train"],
     },
+    n_parameters=248_000_000,
+    memory_usage_mb=944,
+    max_tokens=None,
+    embed_dim=768,
+    license="apache-2.0",
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=True,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 flant5_large = ModelMeta(
@@ -374,7 +433,7 @@ flant5_large = ModelMeta(
         fp_options="float16",
     ),
     name="google/flan-t5-large",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="0613663d0d48ea86ba8cb3d7a44f0f65dc596a2a",
     release_date="2022-10-21",
@@ -390,6 +449,17 @@ flant5_large = ModelMeta(
         "quasc": ["train"],
         "qed": ["train"],
     },
+    n_parameters=783_000_000,
+    max_tokens=1024,
+    memory_usage_mb=2987,
+    embed_dim=None,
+    license="apache-2.0",
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 flant5_xl = ModelMeta(
@@ -400,7 +470,7 @@ flant5_xl = ModelMeta(
         fp_options="float16",
     ),
     name="google/flan-t5-xl",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="7d6315df2c2fb742f0f5b556879d730926ca9001",
     release_date="2022-10-21",
@@ -416,6 +486,17 @@ flant5_xl = ModelMeta(
         "quasc": ["train"],
         "qed": ["train"],
     },
+    n_parameters=2_850_000_000,
+    memory_usage_mb=10871,
+    max_tokens=None,
+    embed_dim=2048,
+    license="apache-2.0",
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 flant5_xxl = ModelMeta(
@@ -426,7 +507,7 @@ flant5_xxl = ModelMeta(
         fp_options="float16",
     ),
     name="google/flan-t5-xxl",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="ae7c9136adc7555eeccc78cdd960dfd60fb346ce",
     release_date="2022-10-21",
@@ -442,6 +523,17 @@ flant5_xxl = ModelMeta(
         "quasc": ["train"],
         "qed": ["train"],
     },
+    n_parameters=11_300_000_000,
+    memory_usage_mb=42980,
+    max_tokens=None,
+    embed_dim=4096,
+    license="apache-2.0",
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 
@@ -453,10 +545,22 @@ llama2_7b = ModelMeta(
         fp_options="float16",
     ),
     name="meta-llama/Llama-2-7b-hf",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="01c7f73d771dfac7d292323805ebc428287df4f9",
     release_date="2023-07-18",
+    n_parameters=6_740_000_000,
+    memory_usage_mb=None,
+    max_tokens=None,
+    embed_dim=None,
+    license=None,  # llama2
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    training_datasets=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 llama2_7b_chat = ModelMeta(
@@ -467,10 +571,22 @@ llama2_7b_chat = ModelMeta(
         fp_options="float16",
     ),
     name="meta-llama/Llama-2-7b-chat-hf",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="f5db02db724555f92da89c216ac04704f23d4590",
     release_date="2023-07-18",
+    n_parameters=None,
+    memory_usage_mb=None,
+    max_tokens=None,
+    embed_dim=None,
+    license=None,
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    training_datasets=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 mistral_7b = ModelMeta(
@@ -481,10 +597,22 @@ mistral_7b = ModelMeta(
         fp_options="float16",
     ),
     name="mistralai/Mistral-7B-Instruct-v0.2",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="3ad372fc79158a2148299e3318516c786aeded6c",
     release_date="2023-12-11",
+    n_parameters=None,
+    memory_usage_mb=None,
+    max_tokens=None,
+    embed_dim=None,
+    license=None,
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    training_datasets=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 followir_7b = ModelMeta(
@@ -495,116 +623,127 @@ followir_7b = ModelMeta(
         fp_options="float16",
     ),
     name="jhu-clsp/FollowIR-7B",
-    languages=["eng_Latn"],
+    languages=["eng-Latn"],
     open_weights=True,
     revision="4d25d437e38b510c01852070c0731e8f6e1875d1",
     release_date="2024-04-29",
     training_datasets={"jhu-clsp/FollowIR-train": ["train"]},
+    n_parameters=7_240_000_000,
+    memory_usage_mb=13813,
+    max_tokens=None,
+    embed_dim=None,
+    license="apache-2.0",
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 
 mt5_languages = [
-    "afr_Latn",
-    "sqi_Latn",
-    "amh_Ethi",
-    "ara_Arab",
-    "hye_Armn",
-    "aze_Latn",
-    "eus_Latn",
-    "bel_Cyrl",
-    "ben_Beng",
-    "bul_Cyrl",
-    "mya_Mymr",
-    "cat_Latn",
-    "ceb_Latn",
-    "nya_Latn",
-    "zho_Hans",
-    "cos_Latn",
-    "ces_Latn",
-    "dan_Latn",
-    "nld_Latn",
-    "eng_Latn",
-    "epo_Latn",
-    "est_Latn",
-    "fil_Latn",
-    "fin_Latn",
-    "fra_Latn",
-    "glg_Latn",
-    "kat_Geor",
-    "deu_Latn",
-    "ell_Grek",
-    "guj_Gujr",
-    "hat_Latn",
-    "hau_Latn",
-    "haw_Latn",
-    "heb_Hebr",
-    "hin_Deva",
-    "hmn_Latn",
-    "hun_Latn",
-    "isl_Latn",
-    "ibo_Latn",
-    "ind_Latn",
-    "gle_Latn",
-    "ita_Latn",
-    "jpn_Jpan",
-    "jav_Latn",
-    "kan_Knda",
-    "kaz_Cyrl",
-    "khm_Khmr",
-    "kor_Hang",
-    "kur_Latn",
-    "kir_Cyrl",
-    "lao_Laoo",
-    "lat_Latn",
-    "lav_Latn",
-    "lit_Latn",
-    "ltz_Latn",
-    "mkd_Cyrl",
-    "mlg_Latn",
-    "msa_Latn",
-    "mal_Mlym",
-    "mlt_Latn",
-    "mri_Latn",
-    "mar_Deva",
-    "mon_Cyrl",
-    "nep_Deva",
-    "nor_Latn",
-    "pus_Arab",
-    "fas_Arab",
-    "pol_Latn",
-    "por_Latn",
-    "pan_Guru",
-    "ron_Latn",
-    "rus_Cyrl",
-    "smo_Latn",
-    "gla_Latn",
-    "srp_Cyrl",
-    "sna_Latn",
-    "snd_Arab",
-    "sin_Sinh",
-    "slk_Latn",
-    "slv_Latn",
-    "som_Latn",
-    "sot_Latn",
-    "spa_Latn",
-    "sun_Latn",
-    "swa_Latn",
-    "swe_Latn",
-    "tgk_Cyrl",
-    "tam_Taml",
-    "tel_Telu",
-    "tha_Thai",
-    "tur_Latn",
-    "ukr_Cyrl",
-    "urd_Arab",
-    "uzb_Latn",
-    "vie_Latn",
-    "cym_Latn",
-    "fry_Latn",
-    "xho_Latn",
-    "yid_Hebr",
-    "yor_Latn",
-    "zul_Latn",
+    "afr-Latn",
+    "sqi-Latn",
+    "amh-Ethi",
+    "ara-Arab",
+    "hye-Armn",
+    "aze-Latn",
+    "eus-Latn",
+    "bel-Cyrl",
+    "ben-Beng",
+    "bul-Cyrl",
+    "mya-Mymr",
+    "cat-Latn",
+    "ceb-Latn",
+    "nya-Latn",
+    "zho-Hans",
+    "cos-Latn",
+    "ces-Latn",
+    "dan-Latn",
+    "nld-Latn",
+    "eng-Latn",
+    "epo-Latn",
+    "est-Latn",
+    "fil-Latn",
+    "fin-Latn",
+    "fra-Latn",
+    "glg-Latn",
+    "kat-Geor",
+    "deu-Latn",
+    "ell-Grek",
+    "guj-Gujr",
+    "hat-Latn",
+    "hau-Latn",
+    "haw-Latn",
+    "heb-Hebr",
+    "hin-Deva",
+    "hmn-Latn",
+    "hun-Latn",
+    "isl-Latn",
+    "ibo-Latn",
+    "ind-Latn",
+    "gle-Latn",
+    "ita-Latn",
+    "jpn-Jpan",
+    "jav-Latn",
+    "kan-Knda",
+    "kaz-Cyrl",
+    "khm-Khmr",
+    "kor-Hang",
+    "kur-Latn",
+    "kir-Cyrl",
+    "lao-Laoo",
+    "lat-Latn",
+    "lav-Latn",
+    "lit-Latn",
+    "ltz-Latn",
+    "mkd-Cyrl",
+    "mlg-Latn",
+    "msa-Latn",
+    "mal-Mlym",
+    "mlt-Latn",
+    "mri-Latn",
+    "mar-Deva",
+    "mon-Cyrl",
+    "nep-Deva",
+    "nor-Latn",
+    "pus-Arab",
+    "fas-Arab",
+    "pol-Latn",
+    "por-Latn",
+    "pan-Guru",
+    "ron-Latn",
+    "rus-Cyrl",
+    "smo-Latn",
+    "gla-Latn",
+    "srp-Cyrl",
+    "sna-Latn",
+    "snd-Arab",
+    "sin-Sinh",
+    "slk-Latn",
+    "slv-Latn",
+    "som-Latn",
+    "sot-Latn",
+    "spa-Latn",
+    "sun-Latn",
+    "swa-Latn",
+    "swe-Latn",
+    "tgk-Cyrl",
+    "tam-Taml",
+    "tel-Telu",
+    "tha-Thai",
+    "tur-Latn",
+    "ukr-Cyrl",
+    "urd-Arab",
+    "uzb-Latn",
+    "vie-Latn",
+    "cym-Latn",
+    "fry-Latn",
+    "xho-Latn",
+    "yid-Hebr",
+    "yor-Latn",
+    "zul-Latn",
 ]
 
 mt5_base_mmarco_v2 = ModelMeta(
@@ -620,6 +759,17 @@ mt5_base_mmarco_v2 = ModelMeta(
     revision="cc0a949b9f21efcaba45c8cabb998ad02ce8d4e7",
     release_date="2022-01-05",
     training_datasets={"msmarco": ["train"]},
+    n_parameters=None,
+    memory_usage_mb=None,
+    max_tokens=None,
+    embed_dim=None,
+    license="mit",
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
 
 mt5_13b_mmarco_100k = ModelMeta(
@@ -634,4 +784,16 @@ mt5_13b_mmarco_100k = ModelMeta(
     open_weights=True,
     revision="e1a4317e102a525ea9e16745ad21394a4f1bffbc",
     release_date="2022-11-04",
+    n_parameters=None,
+    memory_usage_mb=None,
+    max_tokens=None,
+    embed_dim=None,
+    license=None,
+    public_training_code=None,
+    public_training_data=None,
+    similarity_fn_name=None,
+    use_instructions=None,
+    training_datasets=None,
+    framework=["PyTorch"],
+    is_cross_encoder=True,
 )
