@@ -2,15 +2,19 @@ from __future__ import annotations
 
 from .ara.NamaaMrTydiReranking import *
 from .eng.AskUbuntuDupQuestions import *
+from .eng.BuiltBenchReranking import *
 from .eng.MindSmallReranking import *
 from .eng.SciDocsReranking import *
 from .eng.StackOverflowDupQuestions import *
 from .eng.WebLINXCandidatesReranking import *
 from .fra.AlloprofReranking import *
 from .fra.SyntecReranking import *
+from .jpn.JaCWIRReranking import *
+from .jpn.JQaRAReranking import *
 from .jpn.MMarcoReranking import *
 from .multilingual.ESCIReranking import *
 from .multilingual.MIRACLReranking import *
 from .multilingual.WikipediaRerankingMultilingual import *
+from .multilingual.XGlueWPRReranking import *
 from .rus.RuBQReranking import *
 from .zho.CMTEBReranking import *
