@@ -5,6 +5,7 @@ from .code.AppsRetrieval import *
 from .code.CodeEditSearchRetrieval import *
 from .code.CodeFeedbackMTRetrieval import *
 from .code.CodeFeedbackSTRetrieval import *
+from .code.CodeRAG import *
 from .code.CodeSearchNetCCRetrieval import *
 from .code.CodeSearchNetRetrieval import *
 from .code.CodeTransOceanContestRetrieval import *
@@ -29,6 +30,9 @@ from .eng.AlphaNLIRetrieval import *
 from .eng.ARCChallengeRetrieval import *
 from .eng.ArguAnaRetrieval import *
 from .eng.BrightRetrieval import *
+from .eng.BuiltBenchRetrieval import *
+from .eng.ChemHotpotQARetrieval import *
+from .eng.ChemNQRetrieval import *
 from .eng.ClimateFEVERRetrieval import *
 from .eng.CQADupstackAndroidRetrieval import *
 from .eng.CQADupstackEnglishRetrieval import *
@@ -83,6 +87,7 @@ from .eng.NQRetrieval import *
 from .eng.PiqaRetrieval import *
 from .eng.QuailRetrieval import *
 from .eng.QuoraRetrieval import *
+from .eng.R2MEDRetrieval import *
 from .eng.RARbCodeRetrieval import *
 from .eng.RARbMathRetrieval import *
 from .eng.SCIDOCSRetrieval import *
@@ -101,14 +106,18 @@ from .eng.Touche2020Retrieval import *
 from .eng.TRECCOVIDRetrieval import *
 from .eng.WinoGrandeRetrieval import *
 from .est.estqa import *
+from .fas.BEIRFa import *
+from .fas.FaMTEBRetrieval import *
 from .fra.AlloprofRetrieval import *
 from .fra.BSARDRetrieval import *
 from .fra.FQuADRetrieval import *
 from .fra.SyntecRetrieval import *
 from .hun.HunSum2 import *
+from .jpn.JaCWIRRetrieval import *
 from .jpn.JaGovFaqsRetrieval import *
 from .jpn.JaqketRetrieval import *
 from .jpn.JaQuADRetrieval import *
+from .jpn.NLPJournalAbsArticleRetrieval import *
 from .jpn.NLPJournalAbsIntroRetrieval import *
 from .jpn.NLPJournalTitleAbsRetrieval import *
 from .jpn.NLPJournalTitleIntroRetrieval import *
@@ -122,6 +131,7 @@ from .multilingual.CUREv1Retrieval import *
 from .multilingual.IndicQARetrieval import *
 from .multilingual.MintakaRetrieval import *
 from .multilingual.MIRACLRetrieval import *
+from .multilingual.MKQARetrieval import *
 from .multilingual.MLQARetrieval import *
 from .multilingual.MrTidyRetrieval import *
 from .multilingual.MultiLongDocRetrieval import *
@@ -129,10 +139,37 @@ from .multilingual.NeuCLIR2022Retrieval import *
 from .multilingual.NeuCLIR2023Retrieval import *
 from .multilingual.PublicHealthQARetrieval import *
 from .multilingual.StatcanDialogueDatasetRetrieval import *
+from .multilingual.WebFAQRetrieval import *
 from .multilingual.WikipediaRetrievalMultilingual import *
 from .multilingual.XMarketRetrieval import *
 from .multilingual.XPQARetrieval import *
 from .multilingual.XQuADRetrieval import *
+from .nld.ArguAnaNLRetrieval import *
+from .nld.ClimateFEVERNLRetrieval import *
+from .nld.CQADupstackAndroidNLRetrieval import *
+from .nld.CQADupstackEnglishNLRetrieval import *
+from .nld.CQADupstackGamingNLRetrieval import *
+from .nld.CQADupstackGisNLRetrieval import *
+from .nld.CQADupstackMathematicaNLRetrieval import *
+from .nld.CQADupstackPhysicsNLRetrieval import *
+from .nld.CQADupstackProgrammersNLRetrieval import *
+from .nld.CQADupstackStatsNLRetrieval import *
+from .nld.CQADupstackTexNLRetrieval import *
+from .nld.CQADupstackUnixNLRetrieval import *
+from .nld.CQADupstackWebmastersNLRetrieval import *
+from .nld.CQADupstackWordpressNLRetrieval import *
+from .nld.DBPediaNLRetrieval import *
+from .nld.FEVERNLRetrieval import *
+from .nld.FiQA2018NLRetrieval import *
+from .nld.HotpotQANLRetrieval import *
+from .nld.MMARCONLRetrieval import *
+from .nld.NFCorpusNLRetrieval import *
+from .nld.NQNLRetrieval import *
+from .nld.QuoraNLRetrieval import *
+from .nld.SCIDOCSNLRetrieval import *
+from .nld.SciFactNLRetrieval import *
+from .nld.Touche2020NLRetrieval import *
+from .nld.TRECCOVIDNLRetrieval import *
 from .nob.norquad import *
 from .nob.snl_retrieval import *
 from .pol.ArguAnaPLRetrieval import *
@@ -155,6 +192,8 @@ from .spa.SpanishPassageRetrievalS2S import *
 from .swe.SwednRetrieval import *
 from .swe.SweFaqRetrieval import *
 from .tur.TurHistQuad import *
+from .vie.GreenNodeTableMarkdownRetrieval import *
 from .vie.VieQuADRetrieval import *
+from .vie.ZacLegalTextRetrieval import *
 from .zho.CMTEBRetrieval import *
 from .zho.LeCaRDv2Retrieval import *
